@@ -241,10 +241,8 @@ int virNetServerClientAddFilter(virNetServerClientPtr client,
     virNetServerClientFilterPtr *place;
     int ret;
 
-    if (VIR_ALLOC(filter) < 0) {
-        virReportOOMError();
+    if (VIR_ALLOC(filter) < 0)
         return -1;
-    }
 
     virObjectLock(client);
 
@@ -316,7 +314,6 @@ virNetServerClientCheckAccess(virNetServerClientPtr client)
      */
     confirm->bufferLength = 1;
     if (VIR_ALLOC_N(confirm->buffer, confirm->bufferLength) < 0) {
-        virReportOOMError();
         virNetMessageFree(confirm);
         return -1;
     }
@@ -378,10 +375,8 @@ virNetServerClientNewInternal(virNetSocketPtr sock,
     if (!(client->rx = virNetMessageNew(true)))
         goto error;
     client->rx->bufferLength = VIR_NET_MESSAGE_LEN_MAX;
-    if (VIR_ALLOC_N(client->rx->buffer, client->rx->bufferLength) < 0) {
-        virReportOOMError();
+    if (VIR_ALLOC_N(client->rx->buffer, client->rx->bufferLength) < 0)
         goto error;
-    }
     client->nrequests = 1;
 
     PROBE(RPC_SERVER_CLIENT_NEW,
@@ -657,7 +652,9 @@ virNetServerClientCreateIdentity(virNetServerClientPtr client)
     char *processid = NULL;
     char *processtime = NULL;
     char *username = NULL;
+    char *userid = NULL;
     char *groupname = NULL;
+    char *groupid = NULL;
 #if WITH_SASL
     char *saslname = NULL;
 #endif
@@ -677,18 +674,18 @@ virNetServerClientCreateIdentity(virNetServerClientPtr client)
 
         if (!(username = virGetUserName(uid)))
             goto cleanup;
+        if (virAsprintf(&userid, "%d", (int)uid) < 0)
+            goto cleanup;
         if (!(groupname = virGetGroupName(gid)))
             goto cleanup;
+        if (virAsprintf(&groupid, "%d", (int)gid) < 0)
+            goto cleanup;
         if (virAsprintf(&processid, "%llu",
-                        (unsigned long long)pid) < 0) {
-            virReportOOMError();
+                        (unsigned long long)pid) < 0)
             goto cleanup;
-        }
         if (virAsprintf(&processtime, "%llu",
-                        timestamp) < 0) {
-            virReportOOMError();
+                        timestamp) < 0)
             goto cleanup;
-        }
     }
 
 #if WITH_SASL
@@ -719,11 +716,21 @@ virNetServerClientCreateIdentity(virNetServerClientPtr client)
                            VIR_IDENTITY_ATTR_UNIX_USER_NAME,
                            username) < 0)
         goto error;
+    if (userid &&
+        virIdentitySetAttr(ret,
+                           VIR_IDENTITY_ATTR_UNIX_USER_ID,
+                           userid) < 0)
+        goto error;
     if (groupname &&
         virIdentitySetAttr(ret,
                            VIR_IDENTITY_ATTR_UNIX_GROUP_NAME,
                            groupname) < 0)
         goto error;
+    if (groupid &&
+        virIdentitySetAttr(ret,
+                           VIR_IDENTITY_ATTR_UNIX_GROUP_ID,
+                           groupid) < 0)
+        goto error;
     if (processid &&
         virIdentitySetAttr(ret,
                            VIR_IDENTITY_ATTR_UNIX_PROCESS_ID,
@@ -754,7 +761,9 @@ virNetServerClientCreateIdentity(virNetServerClientPtr client)
 
 cleanup:
     VIR_FREE(username);
+    VIR_FREE(userid);
     VIR_FREE(groupname);
+    VIR_FREE(groupid);
     VIR_FREE(processid);
     VIR_FREE(processtime);
     VIR_FREE(seccontext);
@@ -1243,7 +1252,6 @@ readmore:
                 client->rx->bufferLength = VIR_NET_MESSAGE_LEN_MAX;
                 if (VIR_ALLOC_N(client->rx->buffer,
                                 client->rx->bufferLength) < 0) {
-                    virReportOOMError();
                     client->wantClose = true;
                 } else {
                     client->nrequests++;
@@ -1346,7 +1354,6 @@ virNetServerClientDispatchWrite(virNetServerClientPtr client)
                     virNetMessageClear(msg);
                     msg->bufferLength = VIR_NET_MESSAGE_LEN_MAX;
                     if (VIR_ALLOC_N(msg->buffer, msg->bufferLength) < 0) {
-                        virReportOOMError();
                         virNetMessageFree(msg);
                         return;
                     }
