@@ -1450,7 +1450,7 @@ storageVolLookupByPath(virConnectPtr conn,
         virStoragePoolObjLock(driver->pools.objs[i]);
         if (virStoragePoolObjIsActive(driver->pools.objs[i])) {
             virStorageVolDefPtr vol;
-            const char *stable_path;
+            char *stable_path;
 
             stable_path = virStorageBackendStablePath(driver->pools.objs[i],
                                                       cleanpath,
