@@ -53,9 +53,10 @@ int bind(int sockfd ATTRIBUTE_UNUSED,
 # include "virutil.h"
 # include "virerror.h"
 # include "viralloc.h"
+# include "virfile.h"
 # include "virlog.h"
-
 # include "virportallocator.h"
+# include "virstring.h"
 
 # define VIR_FROM_THIS VIR_FROM_RPC
 
@@ -66,6 +67,9 @@ static int testAllocAll(const void *args ATTRIBUTE_UNUSED)
     int ret = -1;
     unsigned short p1, p2, p3, p4, p5, p6, p7;
 
+    if (!alloc)
+        return -1;
+
     if (virPortAllocatorAcquire(alloc, &p1) < 0)
         goto cleanup;
     if (p1 != 5901) {
@@ -136,6 +140,9 @@ static int testAllocReuse(const void *args ATTRIBUTE_UNUSED)
     int ret = -1;
     unsigned short p1, p2, p3, p4;
 
+    if (!alloc)
+        return -1;
+
     if (virPortAllocatorAcquire(alloc, &p1) < 0)
         goto cleanup;
     if (p1 != 5901) {
