@@ -20,13 +20,16 @@
 
 #include <config.h>
 
-#include <stdlib.h>
-
-#include "virsystemd.h"
-#include "virlog.h"
 #include "testutils.h"
 
-#define VIR_FROM_THIS VIR_FROM_NONE
+#ifdef __linux__
+
+# include <stdlib.h>
+
+# include "virsystemd.h"
+# include "virlog.h"
+
+# define VIR_FROM_THIS VIR_FROM_NONE
 
 static int testCreateContainer(const void *opaque ATTRIBUTE_UNUSED)
 {
@@ -51,6 +54,18 @@ static int testCreateContainer(const void *opaque ATTRIBUTE_UNUSED)
     return 0;
 }
 
+static int testTerminateContainer(const void *opaque ATTRIBUTE_UNUSED)
+{
+    if (virSystemdTerminateMachine("demo",
+                                   "lxc",
+                                   true) < 0) {
+        fprintf(stderr, "%s", "Failed to terminate LXC machine\n");
+        return -1;
+    }
+
+    return 0;
+}
+
 static int testCreateMachine(const void *opaque ATTRIBUTE_UNUSED)
 {
     unsigned char uuid[VIR_UUID_BUFLEN] = {
@@ -74,6 +89,18 @@ static int testCreateMachine(const void *opaque ATTRIBUTE_UNUSED)
     return 0;
 }
 
+static int testTerminateMachine(const void *opaque ATTRIBUTE_UNUSED)
+{
+    if (virSystemdTerminateMachine("demo",
+                                   "qemu",
+                                   false) < 0) {
+        fprintf(stderr, "%s", "Failed to terminate KVM machine\n");
+        return -1;
+    }
+
+    return 0;
+}
+
 static int testCreateNoSystemd(const void *opaque ATTRIBUTE_UNUSED)
 {
     unsigned char uuid[VIR_UUID_BUFLEN] = {
@@ -94,9 +121,11 @@ static int testCreateNoSystemd(const void *opaque ATTRIBUTE_UNUSED)
                                       123,
                                       false,
                                       NULL)) == 0) {
+        unsetenv("FAIL_NO_SERVICE");
         fprintf(stderr, "%s", "Unexpected create machine success\n");
         return -1;
     }
+    unsetenv("FAIL_NO_SERVICE");
 
     if (rv != -2) {
         fprintf(stderr, "%s", "Unexpected create machine error\n");
@@ -126,9 +155,11 @@ static int testCreateBadSystemd(const void *opaque ATTRIBUTE_UNUSED)
                                       123,
                                       false,
                                       NULL)) == 0) {
+        unsetenv("FAIL_BAD_SERVICE");
         fprintf(stderr, "%s", "Unexpected create machine success\n");
         return -1;
     }
+    unsetenv("FAIL_BAD_SERVICE");
 
     if (rv != -1) {
         fprintf(stderr, "%s", "Unexpected create machine error\n");
@@ -177,14 +208,18 @@ mymain(void)
 
     if (virtTestRun("Test create container ", 1, testCreateContainer, NULL) < 0)
         ret = -1;
+    if (virtTestRun("Test terminate container ", 1, testTerminateContainer, NULL) < 0)
+        ret = -1;
     if (virtTestRun("Test create machine ", 1, testCreateMachine, NULL) < 0)
         ret = -1;
+    if (virtTestRun("Test terminate machine ", 1, testTerminateMachine, NULL) < 0)
+        ret = -1;
     if (virtTestRun("Test create no systemd ", 1, testCreateNoSystemd, NULL) < 0)
         ret = -1;
     if (virtTestRun("Test create bad systemd ", 1, testCreateBadSystemd, NULL) < 0)
         ret = -1;
 
-#define TEST_SCOPE(name, partition, unitname)                           \
+# define TEST_SCOPE(name, partition, unitname)                          \
     do {                                                                \
         struct testScopeData data = {                                   \
             name, partition, unitname                                   \
@@ -205,3 +240,11 @@ mymain(void)
 }
 
 VIRT_TEST_MAIN_PRELOAD(mymain, abs_builddir "/.libs/virsystemdmock.so")
+
+#else
+int
+main(void)
+{
+    return EXIT_AM_SKIP;
+}
+#endif
