@@ -11,6 +11,9 @@
 # include "internal.h"
 # include "viralloc.h"
 # include "vmx/vmx.h"
+# include "virstring.h"
+
+# define VIR_FROM_THIS VIR_FROM_VMWARE
 
 static virCapsPtr caps;
 static virDomainXMLOptionPtr xmlopt;
@@ -70,51 +73,38 @@ testCapsInit(void)
 static int
 testCompareFiles(const char *vmx, const char *xml)
 {
-    int result = -1;
+    int ret = -1;
     char *vmxData = NULL;
     char *xmlData = NULL;
     char *formatted = NULL;
     virDomainDefPtr def = NULL;
-    virErrorPtr err = NULL;
 
-    if (virtTestLoadFile(vmx, &vmxData) < 0) {
-        goto failure;
-    }
+    if (virtTestLoadFile(vmx, &vmxData) < 0)
+        goto cleanup;
 
-    if (virtTestLoadFile(xml, &xmlData) < 0) {
-        goto failure;
-    }
+    if (virtTestLoadFile(xml, &xmlData) < 0)
+        goto cleanup;
 
-    def = virVMXParseConfig(&ctx, xmlopt, vmxData);
+    if (!(def = virVMXParseConfig(&ctx, xmlopt, vmxData)))
+        goto cleanup;
 
-    if (def == NULL) {
-        err = virGetLastError();
-        fprintf(stderr, "ERROR: %s\n", err != NULL ? err->message : "<unknown>");
-        goto failure;
-    }
-
-    formatted = virDomainDefFormat(def, VIR_DOMAIN_XML_SECURE);
-
-    if (formatted == NULL) {
-        err = virGetLastError();
-        fprintf(stderr, "ERROR: %s\n", err != NULL ? err->message : "<unknown>");
-        goto failure;
-    }
+    if (!(formatted = virDomainDefFormat(def, VIR_DOMAIN_XML_SECURE)))
+        goto cleanup;
 
     if (STRNEQ(xmlData, formatted)) {
         virtTestDifference(stderr, xmlData, formatted);
-        goto failure;
+        goto cleanup;
     }
 
-    result = 0;
+    ret = 0;
 
-  failure:
+  cleanup:
     VIR_FREE(vmxData);
     VIR_FREE(xmlData);
     VIR_FREE(formatted);
     virDomainDefFree(def);
 
-    return result;
+    return ret;
 }
 
 struct testInfo {
@@ -125,7 +115,7 @@ struct testInfo {
 static int
 testCompareHelper(const void *data)
 {
-    int result = -1;
+    int ret = -1;
     const struct testInfo *info = data;
     char *vmx = NULL;
     char *xml = NULL;
@@ -137,13 +127,13 @@ testCompareHelper(const void *data)
         goto cleanup;
     }
 
-    result = testCompareFiles(vmx, xml);
+    ret = testCompareFiles(vmx, xml);
 
   cleanup:
     VIR_FREE(vmx);
     VIR_FREE(xml);
 
-    return result;
+    return ret;
 }
 
 static char *
@@ -158,11 +148,8 @@ testParseVMXFileName(const char *fileName, void *opaque ATTRIBUTE_UNUSED)
 
     if (STRPREFIX(fileName, "/vmfs/volumes/")) {
         /* Found absolute path referencing a file inside a datastore */
-        copyOfFileName = strdup(fileName);
-
-        if (copyOfFileName == NULL) {
+        if (VIR_STRDUP(copyOfFileName, fileName) < 0)
             goto cleanup;
-        }
 
         /* Expected format: '/vmfs/volumes/<datastore>/<path>' */
         if ((tmp = STRSKIP(copyOfFileName, "/vmfs/volumes/")) == NULL ||
@@ -176,7 +163,7 @@ testParseVMXFileName(const char *fileName, void *opaque ATTRIBUTE_UNUSED)
             goto cleanup;
     } else if (STRPREFIX(fileName, "/")) {
         /* Found absolute path referencing a file outside a datastore */
-        src = strdup(fileName);
+        ignore_value(VIR_STRDUP(src, fileName));
     } else if (strchr(fileName, '/') != NULL) {
         /* Found relative path, this is not supported */
         src = NULL;
@@ -195,7 +182,7 @@ testParseVMXFileName(const char *fileName, void *opaque ATTRIBUTE_UNUSED)
 static int
 mymain(void)
 {
-    int result = 0;
+    int ret = 0;
 
 # define DO_TEST(_in, _out)                                                   \
         do {                                                                  \
@@ -203,7 +190,7 @@ mymain(void)
             virResetLastError();                                              \
             if (virtTestRun("VMware VMX-2-XML "_in" -> "_out, 1,              \
                             testCompareHelper, &info) < 0) {                  \
-                result = -1;                                                  \
+                ret = -1;                                                     \
             }                                                                 \
         } while (0)
 
@@ -237,8 +224,12 @@ mymain(void)
 
     DO_TEST("cdrom-scsi-file", "cdrom-scsi-file");
     DO_TEST("cdrom-scsi-device", "cdrom-scsi-device");
+    DO_TEST("cdrom-scsi-raw-device", "cdrom-scsi-raw-device");
+    DO_TEST("cdrom-scsi-raw-auto-detect", "cdrom-scsi-raw-auto-detect");
     DO_TEST("cdrom-ide-file", "cdrom-ide-file");
     DO_TEST("cdrom-ide-device", "cdrom-ide-device");
+    DO_TEST("cdrom-ide-raw-device", "cdrom-ide-raw-device");
+    DO_TEST("cdrom-ide-raw-auto-detect", "cdrom-ide-raw-auto-detect");
 
     DO_TEST("floppy-file", "floppy-file");
     DO_TEST("floppy-device", "floppy-device");
@@ -284,6 +275,8 @@ mymain(void)
     DO_TEST("ws-in-the-wild-1", "ws-in-the-wild-1");
     DO_TEST("ws-in-the-wild-2", "ws-in-the-wild-2");
 
+    DO_TEST("fusion-in-the-wild-1", "fusion-in-the-wild-1");
+
     DO_TEST("annotation", "annotation");
 
     DO_TEST("smbios", "smbios");
@@ -293,7 +286,7 @@ mymain(void)
     virObjectUnref(caps);
     virObjectUnref(xmlopt);
 
-    return result == 0 ? EXIT_SUCCESS : EXIT_FAILURE;
+    return ret == 0 ? EXIT_SUCCESS : EXIT_FAILURE;
 }
 
 VIRT_TEST_MAIN(mymain)
